import React, { PropTypes } from 'react';
import intersection from 'lodash.intersection';


const uiColorModifiers = [
    'blue', 'informative',
    'dark-gray', 'active',
    'gray', 'default',
    'red', 'danger',
    'teal', 'primary',
    'white', 'secondary',
    'link'
];

const uiModifiers = PropTypes.oneOf([
    ...uiColorModifiers,
    'mobile-stretched',
    'stretched'
]);

const defaultUIColorModifier = 'default';

export default (Component) => {

    return React.createClass({

        propTypes: {
            ui: PropTypes.oneOfType([
                uiModifiers,
                PropTypes.arrayOf(uiModifiers)
            ])
        },

        getDefaultProps() {
            return {
                ui: defaultUIColorModifier
            };
        },

        render() {
            const { ui } = this.props;
            const uiArray = typeof ui === 'string' ? [ui] : ui;

            const hasUIColorModifier = intersection(uiArray, uiColorModifiers).length > 0;

            return (
                <Component
                    { ...this.props }
                    ui={ hasUIColorModifier ? uiArray : [defaultUIColorModifier, ...uiArray] } />
            );
        }

    });

};
