import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';
import purebem from 'purebem';

import LinkButton from './LinkButton';

import AnchorTestWrapper from '../../test-utils/AnchorTestWrapper';


const TestLinkButton = LinkButton({
    block: purebem.of('test-button'),
    displayName: 'TestLinkButton'
});

describe('LinkButton', () => {

    it('should navigate', () => {
        const wrapper = TestUtils.renderIntoDocument(
            <AnchorTestWrapper>
                <TestLinkButton />
            </AnchorTestWrapper>
        );

        const button = TestUtils.findRenderedComponentWithType(wrapper, TestLinkButton);
        const node = ReactDOM.findDOMNode(button);

        TestUtils.Simulate.click(node);

        expect(wrapper.didNavigate).toBeTruthy();
    });

    it('should not navigate when disabled', () => {
        const wrapper = TestUtils.renderIntoDocument(
            <AnchorTestWrapper>
                <TestLinkButton disabled={ true } />
            </AnchorTestWrapper>
        );

        const button = TestUtils.findRenderedComponentWithType(wrapper, TestLinkButton);
        const node = ReactDOM.findDOMNode(button);

        TestUtils.Simulate.click(node);

        expect(wrapper.didNavigate).toBeFalsy();
    });

});
