import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';
import purebem from 'purebem';

import Checkbox from './Checkbox';

import simulateLabelClick from '../../test-utils/simulateLabelClick';


const TestCheckbox = Checkbox({
    block: purebem.of('test-checkbox'),
    displayName: 'TestCheckbox'
});

describe('Checkbox', () => {

    it('should render <label> as root', () => {
        // make sure we're using a label or our assumption when using 'simulateLabelClick' is false.
        const checkbox = TestUtils.renderIntoDocument(
            <TestCheckbox />
        );

        const node = ReactDOM.findDOMNode(checkbox);
        expect(node.tagName.toLowerCase()).toBe('label');
    });


    it('should be checked when clicked and is unchecked (simulated)', () => {
        let value = false;

        const checkbox = TestUtils.renderIntoDocument(
            <TestCheckbox onChange={ (v) => value = v } value={ value } />
        );

        simulateLabelClick(checkbox);

        expect(value).toBeTruthy();
    });

    it('should be unchecked when clicked and is checked', () => {
        let value = true;

        const checkbox = TestUtils.renderIntoDocument(
            <TestCheckbox onChange={ (v) => value = v } value={ value } />
        );

        simulateLabelClick(checkbox);

        expect(value).toBeFalsy();
    });

    it('should remain unchecked when disabled and clicked', () => {
        let value = false;

        const checkbox = TestUtils.renderIntoDocument(
            <TestCheckbox disabled={ true } onChange={ (v) => value = v } value={ value } />
        );

        simulateLabelClick(checkbox);

        expect(value).toBeFalsy();
    });

    it('should remain checked when disabled and clicked', () => {
        let value = true;

        const checkbox = TestUtils.renderIntoDocument(
            <TestCheckbox disabled={ true } onChange={ (v) => value = v } value={ value } />
        );

        simulateLabelClick(checkbox);

        expect(value).toBeTruthy();
    });

    it('should be checked when using space and is unchecked', () => {
        let value = false;

        const checkbox = TestUtils.renderIntoDocument(
            <TestCheckbox onChange={ (v) => value = v } value={ value } />
        );

        const node = ReactDOM.findDOMNode(checkbox);
        TestUtils.Simulate.keyDown(node, { which: 32 });

        expect(value).toBeTruthy();
    });

    it('should be unchecked when using space and is checked', () => {
        let value = true;

        const checkbox = TestUtils.renderIntoDocument(
            <TestCheckbox onChange={ (v) => value = v } value={ value } />
        );

        const node = ReactDOM.findDOMNode(checkbox);
        TestUtils.Simulate.keyDown(node, { which: 32 });

        expect(value).toBeFalsy();
    });

    it('should remain unchecked when disabled and using space', () => {
        let value = false;

        const checkbox = TestUtils.renderIntoDocument(
            <TestCheckbox disabled={ true } onChange={ (v) => value = v } value={ value } />
        );

        const node = ReactDOM.findDOMNode(checkbox);
        TestUtils.Simulate.keyDown(node, { which: 32 });

        expect(value).toBeFalsy();
    });

    it('should remain checked when disabled and using space', () => {
        let value = true;

        const checkbox = TestUtils.renderIntoDocument(
            <TestCheckbox disabled={ true } onChange={ (v) => value = v } value={ value } />
        );

        const node = ReactDOM.findDOMNode(checkbox);
        TestUtils.Simulate.keyDown(node, { which: 32 });

        expect(value).toBeTruthy();
    });

});
